==> python-fixtures_4.2.5.orig.tar.xz: python-fixtures-4.2.5/fixtures/_fixtures/mockpatch.py <==
# Copyright 2010 United States Government as represented by the
# Administrator of the National Aeronautics and Space Administration.
# Copyright 2013 Hewlett-Packard Development Company, L.P.
# All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License. You may obtain
# a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations
# under the License.

import unittest.mock as mock

import fixtures


class _Base(fixtures.Fixture):
    def _setUp(self):
        _p = self._get_p()
        self.addCleanup(_p.stop)
        self.mock = _p.start()


class MockPatchObject(_Base):
    """Deal with code around mock."""

    def __init__(self, obj, attr, new=None, **kwargs):
        super(MockPatchObject, self).__init__()
        if new is None:
            new = mock.DEFAULT
        self._get_p = lambda: mock.patch.object(obj, attr, new, **kwargs)


class MockPatch(_Base):
    """Deal with code around mock.patch."""

    def __init__(self, obj, new=None, **kwargs):
        super(MockPatch, self).__init__()
        if new is None:
            new = mock.DEFAULT
        self._get_p = lambda: mock.patch(obj, new, **kwargs)


class _MockPatchMultipleMeta(type):
    """Arrange for lazy loading of MockPatchMultiple.DEFAULT."""

    # For strict backward compatibility, ensure that DEFAULT also works as
    # an instance property.
    def __new__(cls, name, bases, namespace, **kwargs):
        namespace['DEFAULT'] = cls.DEFAULT
        return super().__new__(cls, name, bases, namespace, **kwargs)

    # Default value to trigger a MagicMock to be created for a named
    # attribute.
    @property
    def DEFAULT(self):
        return mock.DEFAULT


class MockPatchMultiple(_Base, metaclass=_MockPatchMultipleMeta):
    """Deal with code around mock.patch.multiple."""

    def __init__(self, obj, **kwargs):
        """Initialize the mocks

        Pass name=value to replace obj.name with value.

        Pass name=Multiple.DEFAULT to replace obj.name with a
        MagicMock instance.

        :param obj: Object or name containing values being mocked.
        :type obj: str or object
        :param kwargs: names and values of attributes of obj to be mocked.

        """
        super(MockPatchMultiple, self).__init__()
        self._get_p = lambda: mock.patch.multiple(obj, **kwargs)

==> python-fixtures_4.3.0.orig.tar.xz: python-fixtures-4.3.0/fixtures/_fixtures/mockpatch.py <==
# Copyright 2010 United States Government as represented by the
# Administrator of the National Aeronautics and Space Administration.
# Copyright 2013 Hewlett-Packard Development Company, L.P.
# All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License. You may obtain
# a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations
# under the License.

import unittest.mock as mock
from typing import Any
from collections.abc import Callable

import fixtures


class _Base(fixtures.Fixture):
    _get_p: Callable[[], Any]  # Returns mock._patch or similar
    mock: mock.MagicMock

    def _setUp(self) -> None:
        _p = self._get_p()
        self.addCleanup(_p.stop)
        self.mock = _p.start()


class MockPatchObject(_Base):
    """Deal with code around mock."""

    def __init__(self, obj: Any, attr: str, new: Any = None, **kwargs: Any) -> None:
        super().__init__()
        if new is None:
            new = mock.DEFAULT
        self._get_p: Callable[[], Any] = lambda: mock.patch.object(
            obj, attr, new, **kwargs
        )


class MockPatch(_Base):
    """Deal with code around mock.patch."""

    def __init__(self, obj: str, new: Any = None, **kwargs: Any) -> None:
        super().__init__()
        if new is None:
            new = mock.DEFAULT
        self._get_p: Callable[[], Any] = lambda: mock.patch(obj, new, **kwargs)


class _MockPatchMultipleMeta(type):
    """Arrange for lazy loading of MockPatchMultiple.DEFAULT."""

    # For strict backward compatibility, ensure that DEFAULT also works as
    # an instance property.
    def __new__(
        cls,
        name: str,
        bases: tuple[type, ...],
        namespace: dict[str, Any],
        **kwargs: Any,
    ) -> type:
        namespace["DEFAULT"] = cls.DEFAULT
        return super().__new__(cls, name, bases, namespace, **kwargs)

    # Default value to trigger a MagicMock to be created for a named
    # attribute.
    @property
    def DEFAULT(self) -> Any:
        return mock.DEFAULT


class MockPatchMultiple(_Base, metaclass=_MockPatchMultipleMeta):
    """Deal with code around mock.patch.multiple."""

    def __init__(self, obj: Any, **kwargs: Any) -> None:
        """Initialize the mocks

        Pass name=value to replace obj.name with value.

        Pass name=Multiple.DEFAULT to replace obj.name with a
        MagicMock instance.

        :param obj: Object or name containing values being mocked.
        :type obj: str or object
        :param kwargs: names and values of attributes of obj to be mocked.

        """
        super().__init__()
        self._get_p: Callable[[], Any] = lambda: mock.patch.multiple(obj, **kwargs)
